==> openshift-model-config-6.3.1-sources.jar: io/fabric8/openshift/api/model/config/v1/OperatorHubFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class OperatorHubFluentImpl<A extends OperatorHubFluent<A>> extends BaseFluent<A> implements OperatorHubFluent<A>{
  public OperatorHubFluentImpl() {
  }
  public OperatorHubFluentImpl(OperatorHub instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private OperatorHubSpecBuilder spec;
  private OperatorHubStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public OperatorHubFluent.MetadataNested<A> withNewMetadata() {
    return new OperatorHubFluentImpl.MetadataNestedImpl();
  }
  public OperatorHubFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new OperatorHubFluentImpl.MetadataNestedImpl(item);
  }
  public OperatorHubFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public OperatorHubFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public OperatorHubFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public OperatorHubSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public OperatorHubSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(OperatorHubSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new OperatorHubSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public OperatorHubFluent.SpecNested<A> withNewSpec() {
    return new OperatorHubFluentImpl.SpecNestedImpl();
  }
  public OperatorHubFluent.SpecNested<A> withNewSpecLike(OperatorHubSpec item) {
    return new OperatorHubFluentImpl.SpecNestedImpl(item);
  }
  public OperatorHubFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public OperatorHubFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new OperatorHubSpecBuilder().build());
  }
  public OperatorHubFluent.SpecNested<A> editOrNewSpecLike(OperatorHubSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public OperatorHubStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public OperatorHubStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(OperatorHubStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new OperatorHubStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public OperatorHubFluent.StatusNested<A> withNewStatus() {
    return new OperatorHubFluentImpl.StatusNestedImpl();
  }
  public OperatorHubFluent.StatusNested<A> withNewStatusLike(OperatorHubStatus item) {
    return new OperatorHubFluentImpl.StatusNestedImpl(item);
  }
  public OperatorHubFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public OperatorHubFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new OperatorHubStatusBuilder().build());
  }
  public OperatorHubFluent.StatusNested<A> editOrNewStatusLike(OperatorHubStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    OperatorHubFluentImpl that = (OperatorHubFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<OperatorHubFluent.MetadataNested<N>> implements OperatorHubFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) OperatorHubFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends OperatorHubSpecFluentImpl<OperatorHubFluent.SpecNested<N>> implements OperatorHubFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(OperatorHubSpec item) {
      this.builder = new OperatorHubSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new OperatorHubSpecBuilder(this);
    }
    OperatorHubSpecBuilder builder;
    public N and() {
      return (N) OperatorHubFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends OperatorHubStatusFluentImpl<OperatorHubFluent.StatusNested<N>> implements OperatorHubFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(OperatorHubStatus item) {
      this.builder = new OperatorHubStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new OperatorHubStatusBuilder(this);
    }
    OperatorHubStatusBuilder builder;
    public N and() {
      return (N) OperatorHubFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> openshift-model-config-6.7.0-sources.jar: io/fabric8/openshift/api/model/config/v1/OperatorHubFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class OperatorHubFluentImpl<A extends OperatorHubFluent<A>> extends BaseFluent<A> implements OperatorHubFluent<A>{
  public OperatorHubFluentImpl() {
  }
  public OperatorHubFluentImpl(OperatorHub instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private OperatorHubSpecBuilder spec;
  private OperatorHubStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public OperatorHubFluentImpl.MetadataNested<A> withNewMetadata() {
    return new OperatorHubFluentImpl.MetadataNestedImpl();
  }
  public OperatorHubFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new OperatorHubFluentImpl.MetadataNestedImpl(item);
  }
  public OperatorHubFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public OperatorHubFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public OperatorHubFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public OperatorHubSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public OperatorHubSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(OperatorHubSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new OperatorHubSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public OperatorHubFluentImpl.SpecNested<A> withNewSpec() {
    return new OperatorHubFluentImpl.SpecNestedImpl();
  }
  public OperatorHubFluentImpl.SpecNested<A> withNewSpecLike(OperatorHubSpec item) {
    return new OperatorHubFluentImpl.SpecNestedImpl(item);
  }
  public OperatorHubFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public OperatorHubFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new OperatorHubSpecBuilder().build());
  }
  public OperatorHubFluentImpl.SpecNested<A> editOrNewSpecLike(OperatorHubSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public OperatorHubStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public OperatorHubStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(OperatorHubStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new OperatorHubStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public OperatorHubFluentImpl.StatusNested<A> withNewStatus() {
    return new OperatorHubFluentImpl.StatusNestedImpl();
  }
  public OperatorHubFluentImpl.StatusNested<A> withNewStatusLike(OperatorHubStatus item) {
    return new OperatorHubFluentImpl.StatusNestedImpl(item);
  }
  public OperatorHubFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public OperatorHubFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new OperatorHubStatusBuilder().build());
  }
  public OperatorHubFluentImpl.StatusNested<A> editOrNewStatusLike(OperatorHubStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OperatorHubFluentImpl that = (OperatorHubFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<OperatorHubFluentImpl.MetadataNested<N>> implements OperatorHubFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) OperatorHubFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends OperatorHubSpecFluentImpl<OperatorHubFluentImpl.SpecNested<N>> implements OperatorHubFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(OperatorHubSpec item) {
      this.builder = new OperatorHubSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new OperatorHubSpecBuilder(this);
    }
    OperatorHubSpecBuilder builder;
    public N and() {
      return (N) OperatorHubFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends OperatorHubStatusFluentImpl<OperatorHubFluentImpl.StatusNested<N>> implements OperatorHubFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(OperatorHubStatus item) {
      this.builder = new OperatorHubStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new OperatorHubStatusBuilder(this);
    }
    OperatorHubStatusBuilder builder;
    public N and() {
      return (N) OperatorHubFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
